==> botcity-cloudvision-plugin-0.1.1.tar.gz: botcity-cloudvision-plugin-0.1.1/README.md <==
# BotCity CloudVision Plugin - Python

## 🤖 Computer-vision based UI Automation

Recognize and interact with UI elements using state-of-art computer vision module.

Operate any UI interface independent of the technology or platform (desktop, web, terminal).

## 🐍 Generate Python Code while Interacting with your UI

Use our Development Tool alongside your favorite IDE to select UI components and generate python code.

[![BotCity Studio](https://developers.botcity.dev/github/readme/studio/studio.gif)](https://botcity.atlassian.net/l/c/eBJ6bLLV)

[SIGN UP](https://developers.botcity.dev/app/signup) and download our tools.


## 🚀 Getting Started

### 📦 Prerequisites
* Python 3.7+
* Poppler
* google-cloud-vision
* pdf2image
* Pillow

### 💫 Installing

```bash
pip install botcity-cloudvision-plugin
```

**Attention:** This package also depends on a non-Python dependency, `Poppler`. You can find instructions on how to install Poppler for your favorite OS below.


#### Installing Poppler

Poppler is a PDF rendering library based on the xpdf.

Here is how to install Poppler for Windows, Linux and MacOS.

##### Windows

- Download the latest library from https://github.com/oschwartz10612/poppler-windows/releases/.
- After downloading Poppler, we need to extract to the convenient location generally under C drive.
- In my case, the Poppler library bin directory is `C:\poppler-21.11.0\Library\bin`. Now you need to add this directory (`C:\poppler-21.11.0\Library\bin`) to your environment variable Path.

If you have questions on how to add a directory to your Path environment variable [click here](https://www.architectryan.com/2018/03/17/add-to-the-path-on-windows-10/).

You are now all set!

##### Linux

```bash
apt install poppler-utils
```

##### MacOS

For MacOS please follow the instructions on how to install Poppler available [here](https://macappstore.org/poppler/).

Alternatively, if you are using Anaconda you can install from your favorite channel with:

```bash
conda install poppler
```

### ⭐ Using the Plugin

[![First Automation](https://developers.botcity.dev/github/readme/python-plugins/cloudvision-plugin.png)](https://botcity-dev.github.io/botcity-plugins-python)

## 📚 Documentation

Documentation is available at https://botcity-dev.github.io/botcity-plugins-python.

## 💻 Developers Portal

[![Developers Portal](https://developers.botcity.dev/github/readme/portal.png)](https://botcity.atlassian.net/l/c/boMU4TX9)

## 💬 Forum

[![Forum](https://developers.botcity.dev/github/readme/forum.png)](https://community.botcity.dev/)

## 🌎 BotCity Automation Platform
BotCity is a platform to develop, deploy, manage and maintain automations. Automations can be developed in Python or Java using open-source libraries that are market standard.

### 1️⃣  All in One Platform
Develop, deploy, manage and scale your Automation Ops using All in One platform that provides task queue, runtime environment management, reports, alerts, logs and much more.

[![BotCity Maestro](https://developers.botcity.dev/github/readme/maestro/maestro.png)](https://botcity.atlassian.net/l/c/WWGswYRX)

### 2️⃣  Deploy with a Single Line

Use BotCity command-line interface (CLI) to deploy your bot into a runtime environment with a single line:

[![BotCity CLI](https://developers.botcity.dev/github/readme/cli/botcli.gif)](https://botcity.atlassian.net/l/c/hJHE1ZFv)

### 3️⃣  Manage your Task Queue

[![BotCity Maestro Task Queue](https://developers.botcity.dev/github/readme/maestro/tasks.png)](https://botcity.atlassian.net/l/c/gR3AAd2a)

### 4️⃣  Manage your Runtime Environments

[![BotCity Maestro Machines](https://developers.botcity.dev/github/readme/maestro/machines.png)](https://botcity.atlassian.net/l/c/uDB087nK)

### 5️⃣  Create Alerts and Reports from the Automation Execution

[![BotCity Maestro Alerts](https://developers.botcity.dev/github/readme/maestro/alerts.png)](https://botcity.atlassian.net/l/c/McH09qYw)

### 6️⃣  Create Google Data Studio Dashboards

[![BotCity Maestro Dashboards](https://developers.botcity.dev/github/readme/maestro/dashboard.png)](https://botcity.atlassian.net/l/c/Z1uMY1vX)

### 7️⃣  Create your Community Account

We have a community account for hobbyists and students. Just signup and start automating.

[![Sign Up](https://developers.botcity.dev/github/readme/signup.png)](https://developers.botcity.dev/app/signup)


## ⛑ Support

### 📢 Contact us

If you have questions or comments in general about the framework, we want to know.

You can choose between the channels the one that best fit you:

- [BotCity Community](<https://community.botcity.dev>) (Public)

==> botcity-cloudvision-plugin-0.1.2.tar.gz: botcity-cloudvision-plugin-0.1.2/README.md <==
# BotCity CloudVision Plugin - Python

## 🤖 Computer-vision based UI Automation

Recognize and interact with UI elements using state-of-art computer vision module.

Operate any UI interface independent of the technology or platform (desktop, web, terminal).

## 🐍 Generate Python Code while Interacting with your UI

Use our Development Tool alongside your favorite IDE to select UI components and generate python code.

[![BotCity Studio](https://developers.botcity.dev/github/readme/studio/studio.gif)](https://botcity.atlassian.net/l/c/eBJ6bLLV)

[SIGN UP](https://developers.botcity.dev/app/signup) and download our tools.


## 🚀 Getting Started

### 📦 Prerequisites
* Python 3.7+
* Poppler
* google-cloud-vision
* pdf2image
* Pillow

### 💫 Installing

```bash
pip install botcity-cloudvision-plugin
```

**Attention:** This package also depends on a non-Python dependency, `Poppler`. You can find instructions on how to install Poppler for your favorite OS below.


#### Installing Poppler

Poppler is a PDF rendering library based on the xpdf.

Here is how to install Poppler for Windows, Linux and MacOS.

##### Windows

- Download the latest library from [this website](https://github.com/oschwartz10612/poppler-windows/releases/).
- After downloading Poppler, we need to extract to the convenient location generally under C drive.
- In my case, the Poppler library bin directory is `C:\poppler-21.11.0\Library\bin`. Now you need to add this directory (`C:\poppler-21.11.0\Library\bin`) to your environment variable Path.

If you have questions on how to add a directory to your Path environment variable [click here](https://www.architectryan.com/2018/03/17/add-to-the-path-on-windows-10/).

You are now all set!

##### Linux

```bash
apt install poppler-utils
```

##### MacOS

For MacOS please follow the instructions on how to install Poppler available [here](https://macappstore.org/poppler/).

Alternatively, if you are using Anaconda you can install from your favorite channel with:

```bash
conda install poppler
```

### ⭐ Using the Plugin

[![First Automation](https://developers.botcity.dev/github/readme/python-plugins/cloudvision-plugin.png)](https://botcity-dev.github.io/botcity-plugins-python)

## 📚 Documentation

Documentation is available at https://botcity-dev.github.io/botcity-plugins-python.

## 💻 Developers Portal

[![Developers Portal](https://developers.botcity.dev/github/readme/portal.png)](https://botcity.atlassian.net/l/c/boMU4TX9)

## 💬 Forum

[![Forum](https://developers.botcity.dev/github/readme/forum.png)](https://community.botcity.dev/)

## 🌎 BotCity Automation Platform
BotCity is a platform to develop, deploy, manage and maintain automations. Automations can be developed in Python or Java using open-source libraries that are market standard.

### 1️⃣  All in One Platform
Develop, deploy, manage and scale your Automation Ops using All in One platform that provides task queue, runtime environment management, reports, alerts, logs and much more.

[![BotCity Maestro](https://developers.botcity.dev/github/readme/maestro/maestro.png)](https://botcity.atlassian.net/l/c/WWGswYRX)

### 2️⃣  Deploy with a Single Line

Use BotCity command-line interface (CLI) to deploy your bot into a runtime environment with a single line:

[![BotCity CLI](https://developers.botcity.dev/github/readme/cli/botcli.gif)](https://botcity.atlassian.net/l/c/hJHE1ZFv)

### 3️⃣  Manage your Task Queue

[![BotCity Maestro Task Queue](https://developers.botcity.dev/github/readme/maestro/tasks.png)](https://botcity.atlassian.net/l/c/gR3AAd2a)

### 4️⃣  Manage your Runtime Environments

[![BotCity Maestro Machines](https://developers.botcity.dev/github/readme/maestro/machines.png)](https://botcity.atlassian.net/l/c/uDB087nK)

### 5️⃣  Create Alerts and Reports from the Automation Execution

[![BotCity Maestro Alerts](https://developers.botcity.dev/github/readme/maestro/alerts.png)](https://botcity.atlassian.net/l/c/McH09qYw)

### 6️⃣  Create Google Data Studio Dashboards

[![BotCity Maestro Dashboards](https://developers.botcity.dev/github/readme/maestro/dashboard.png)](https://botcity.atlassian.net/l/c/Z1uMY1vX)

### 7️⃣  Create your Community Account

We have a community account for hobbyists and students. Just signup and start automating.

[![Sign Up](https://developers.botcity.dev/github/readme/signup.png)](https://developers.botcity.dev/app/signup)


## ⛑ Support

### 📢 Contact us

If you have questions or comments in general about the framework, we want to know.

You can choose between the channels the one that best fit you:

- [BotCity Community](<https://community.botcity.dev>) (Public)
